@@ -30,6 +30,9 @@
 #' @references Srivastava, A., Wu, W., Kurtek, S., Klassen, E., Marron, J. S.,
 #'  May 2011. Registration of functional data using fisher-rao metric, 
 #'  arXiv:1103.3817v2 [math.ST].
+#'  @references Tucker, J. D., Wu, W., Srivastava, A.,
+#'  Generative Models for Function Data using Phase and Amplitude Separation, 
+#'  Computational Statistics and Data Analysis (2012), 10.1016/j.csda.2012.12.001. 
 #' @export
 #' @examples
 #' data("simu_data")
@@ -177,7 +180,6 @@ time_warping <- function(f, time, lambda = 0, method = "mean",
 			
 			qun[r] = pvecnorm(mq[,r+1]-mq[,r],2)/pvecnorm(mq[,r],2)
 		}
-		
 		if (qun[r] < 1e-2 || r >=MaxItr){
 			break
 		}
@@ -258,6 +260,6 @@ time_warping <- function(f, time, lambda = 0, method = "mean",
 	}
 	
 	return(list(f0=f[,,1],fn=fn,qn=qn,q0=q0,fmean=fmean,mqn=mqn,gam=gam,
-							orig.var=orig.var,amp.var=amp.var,phase.var=phase.var))
+							orig.var=orig.var,amp.var=amp.var,phase.var=phase.var,qun=qun))
 	
 }
